@@ -300,7 +300,7 @@ void FcitxQtKeySequenceWidgetPrivate::updateShortcutDisplay() {
             if (modifierKeys_ & KeyState::Super)
                 s += "Super+";
             if (modifierKeys_ & KeyState::Ctrl)
-                s += "Contorl+";
+                s += "Control+";
             if (modifierKeys_ & KeyState::Alt)
                 s += "Alt+";
             if (modifierKeys_ & KeyState::Shift)
@@ -419,19 +419,6 @@ void FcitxQtKeySequenceButton::keyPressEvent(QKeyEvent *e) {
         d->updateShortcutDisplay();
         break;
     default:
-
-        if (d->keySequence_.size() == 0 &&
-            !d->modifierKeys_.testAny(~KeyStates(KeyState::Shift))) {
-            // It's the first key and no modifier pressed. Check if this is
-            // allowed
-            if (!(FcitxQtKeySequenceWidgetPrivate::isOkWhenModifierless(
-                      keyQt) ||
-                  d->allowModifierless_)) {
-                // No it's not
-                return;
-            }
-        }
-
         // We now have a valid key press.
         if (keyQt) {
             if ((keyQt == Qt::Key_Backtab) &&
@@ -460,6 +447,11 @@ void FcitxQtKeySequenceButton::keyPressEvent(QKeyEvent *e) {
                 }
             }
 
+            if (d->keySequence_.size() == 0 && !d->allowModifierless_ &&
+                key.states() == 0) {
+                return;
+            }
+
             if (key.isValid()) {
                 d->keySequence_ << key;
             }
